pub trait PrimeCurveParams:
PrimeCurve
+ CurveArithmetic
+ CurveArithmetic<AffinePoint = AffinePoint<Self>>
+ CurveArithmetic<ProjectivePoint = ProjectivePoint<Self>> {
type FieldElement: PrimeField<Repr = FieldBytes<Self>>;
type PointArithmetic: PointArithmetic<Self>;
const EQUATION_A: Self::FieldElement;
const EQUATION_B: Self::FieldElement;
const GENERATOR: (Self::FieldElement, Self::FieldElement);
}Expand description
Parameters for elliptic curves of prime order which can be described by the short Weierstrass equation.
Required Associated Constants
Sourceconst EQUATION_A: Self::FieldElement
const EQUATION_A: Self::FieldElement
Coefficient a in the curve equation.
Sourceconst EQUATION_B: Self::FieldElement
const EQUATION_B: Self::FieldElement
Coefficient b in the curve equation.
Sourceconst GENERATOR: (Self::FieldElement, Self::FieldElement)
const GENERATOR: (Self::FieldElement, Self::FieldElement)
Generator point’s affine coordinates: (x, y).
Required Associated Types
Sourcetype FieldElement: PrimeField<Repr = FieldBytes<Self>>
type FieldElement: PrimeField<Repr = FieldBytes<Self>>
Base field element type.
Sourcetype PointArithmetic: PointArithmetic<Self>
type PointArithmetic: PointArithmetic<Self>
Point arithmetic implementation, might be optimized for this specific curve
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".